﻿using UnityEngine;

public class MotionSampleDisplay : MonoBehaviour
{
    [SerializeField]
    GameObject        left,
                      right;

    public Sprite     sprite;
    public float      timeout;
    private float     start;
    private bool      isInit;
    public MotionNote caller;
    
    private float     acceleration;

    private float     distance = 1.5f,
                      last = 0;
    private Vector3   localScaleLR = new Vector3(0.5f, 0.5f, 0),
                      initialPosL,
                      initialPosR;

    private void Start()
    {
        initialPosL = left .transform.position;
        initialPosR = right.transform.position;
    }
    
    private void OnEnable()
    {
        acceleration = 2 * distance / Mathf.Pow(timeout, 2);
        last = 0;
        isInit = false;
        
        SetObject(left,  initialPosL, true);
        SetObject(right, initialPosR, false);
    }

    void SetObject(GameObject obj, Vector3 initialPos, bool isLeft)
    {
        obj.GetComponent<SpriteRenderer>().sprite = sprite;
        obj.transform.position = initialPos;
        obj.transform.Translate(new Vector3(distance * (isLeft ? -1 : 1), -0.8f, 0));
        obj.transform.localScale = localScaleLR;
    }

    private void Update()
    {
        var current = Time.time;
        if (!isInit)
        {
            isInit = true;
            start = current;
        }

        var delta = current - start;
        if (delta > timeout)
        {
            gameObject.SetActive(false);
            return;
        }

        var movement = acceleration / 2 * (Mathf.Pow(delta, 2) - Mathf.Pow(last, 2));
        left .transform.Translate(new Vector3(movement, 0, 0));
        right.transform.Translate(new Vector3(-movement, 0, 0));

        last = delta;
    }
}